from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, String

Nextflow_Kuberun_V0_1_0 = CommandToolBuilder(tool="nextflow_kuberun", base_command=["nextflow", "kuberun"], inputs=[ToolInput(tag="in_exports_current_system", input_type=Boolean(optional=True), prefix="-E", doc=InputDocumentation(doc="Exports all current system environment\nDefault: false")), ToolInput(tag="in_ansi_log", input_type=Boolean(optional=True), prefix="-ansi-log", doc=InputDocumentation(doc="Enable/disable ANSI console logging")), ToolInput(tag="in_bucket_dir", input_type=Boolean(optional=True), prefix="-bucket-dir", doc=InputDocumentation(doc="Remote bucket where intermediate result files are stored")), ToolInput(tag="in_cache", input_type=Boolean(optional=True), prefix="-cache", doc=InputDocumentation(doc="Enable/disable processes caching")), ToolInput(tag="in_dsl_two", input_type=Boolean(optional=True), prefix="-dsl2", doc=InputDocumentation(doc="Execute the workflow using DSL2 syntax\nDefault: false")), ToolInput(tag="in_dump_channels", input_type=Boolean(optional=True), prefix="-dump-channels", doc=InputDocumentation(doc="Dump channels for debugging purpose")), ToolInput(tag="in_dump_hashes", input_type=Boolean(optional=True), prefix="-dump-hashes", doc=InputDocumentation(doc="Dump task hash keys for debugging purpose\nDefault: false")), ToolInput(tag="in_e_dot", input_type=Boolean(optional=True), prefix="-e.", doc=InputDocumentation(doc="Add the specified variable to execution environment\nSyntax: -e.key=value\nDefault: {}")), ToolInput(tag="in_entry", input_type=Boolean(optional=True), prefix="-entry", doc=InputDocumentation(doc="Entry workflow name to be executed")), ToolInput(tag="in_hub", input_type=Boolean(optional=True), prefix="-hub", doc=InputDocumentation(doc="Service hub where the project is hosted")), ToolInput(tag="in_latest", input_type=Boolean(optional=True), prefix="-latest", doc=InputDocumentation(doc="Pull latest changes before run\nDefault: false")), ToolInput(tag="in_lib", input_type=Boolean(optional=True), prefix="-lib", doc=InputDocumentation(doc="Library extension path")), ToolInput(tag="in_main_script", input_type=Boolean(optional=True), prefix="-main-script", doc=InputDocumentation(doc="The script file to be executed when launching a project directory or\nrepository")), ToolInput(tag="in_assign_mnemonic_name", input_type=Boolean(optional=True), prefix="-name", doc=InputDocumentation(doc="Assign a mnemonic name to the a pipeline run")), ToolInput(tag="in_namespace", input_type=Boolean(optional=True), prefix="-namespace", doc=InputDocumentation(doc="Specify the K8s namespace to use")), ToolInput(tag="in_offline", input_type=Boolean(optional=True), prefix="-offline", doc=InputDocumentation(doc="Do not check for remote project updates\nDefault: false")), ToolInput(tag="in_params_file", input_type=Boolean(optional=True), prefix="-params-file", doc=InputDocumentation(doc="Load script parameters from a JSON/YAML file")), ToolInput(tag="in_pod_image", input_type=Boolean(optional=True), prefix="-pod-image", doc=InputDocumentation(doc="Specify the container image for the Nextflow pod")), ToolInput(tag="in_process_dot", input_type=Boolean(optional=True), prefix="-process.", doc=InputDocumentation(doc="Set process options\nSyntax: -process.key=value\nDefault: {}")), ToolInput(tag="in_profile", input_type=Boolean(optional=True), prefix="-profile", doc=InputDocumentation(doc="Choose a configuration profile")), ToolInput(tag="in_queue_size", input_type=Boolean(optional=True), prefix="-queue-size", doc=InputDocumentation(doc="Max number of processes that can be executed in parallel by each executor")), ToolInput(tag="in_resume", input_type=Boolean(optional=True), prefix="-resume", doc=InputDocumentation(doc="Execute the script using the cached results, useful to continue\nexecutions that was stopped by an error")), ToolInput(tag="in_revision", input_type=Boolean(optional=True), prefix="-revision", doc=InputDocumentation(doc="Revision of the project to run (either a git branch, tag or commit SHA\nnumber)")), ToolInput(tag="in_test", input_type=Boolean(optional=True), prefix="-test", doc=InputDocumentation(doc="Test a script function with the name specified")), ToolInput(tag="in_user", input_type=Boolean(optional=True), prefix="-user", doc=InputDocumentation(doc="Private repository user name")), ToolInput(tag="in_volume_mount", input_type=Boolean(optional=True), prefix="-volume-mount", doc=InputDocumentation(doc="Volume claim mounts eg. my-pvc:/mnt/path")), ToolInput(tag="in_with_cond_a", input_type=Boolean(optional=True), prefix="-with-conda", doc=InputDocumentation(doc="Use the specified Conda environment package or file (must end with\n.yml|.yaml suffix)")), ToolInput(tag="in_with_dag", input_type=Boolean(optional=True), prefix="-with-dag", doc=InputDocumentation(doc="Create pipeline DAG file")), ToolInput(tag="in_with_docker", input_type=Boolean(optional=True), prefix="-with-docker", doc=InputDocumentation(doc="Enable process execution in a Docker container")), ToolInput(tag="in_with_notification", input_type=Boolean(optional=True), prefix="-with-notification", doc=InputDocumentation(doc="Send a notification email on workflow completion to the specified\nrecipients")), ToolInput(tag="in_with_pod_man", input_type=Boolean(optional=True), prefix="-with-podman", doc=InputDocumentation(doc="Enable process execution in a Podman container")), ToolInput(tag="in_with_report", input_type=Boolean(optional=True), prefix="-with-report", doc=InputDocumentation(doc="Create processes execution html report")), ToolInput(tag="in_with_singularity", input_type=Boolean(optional=True), prefix="-with-singularity", doc=InputDocumentation(doc="Enable process execution in a Singularity container")), ToolInput(tag="in_with_timeline", input_type=Boolean(optional=True), prefix="-with-timeline", doc=InputDocumentation(doc="Create processes execution timeline file")), ToolInput(tag="in_with_tower", input_type=Boolean(optional=True), prefix="-with-tower", doc=InputDocumentation(doc="Monitor workflow execution with Seqera Tower service")), ToolInput(tag="in_with_trace", input_type=Boolean(optional=True), prefix="-with-trace", doc=InputDocumentation(doc="Create processes execution tracing file")), ToolInput(tag="in_with_weblog", input_type=Boolean(optional=True), prefix="-with-weblog", doc=InputDocumentation(doc="Send workflow status messages via HTTP to target URL")), ToolInput(tag="in_without_docker", input_type=Boolean(optional=True), prefix="-without-docker", doc=InputDocumentation(doc="Disable process execution with Docker\nDefault: false")), ToolInput(tag="in_without_pod_man", input_type=Boolean(optional=True), prefix="-without-podman", doc=InputDocumentation(doc="Disable process execution in a Podman container")), ToolInput(tag="in_work_dir", input_type=Boolean(optional=True), prefix="-work-dir", doc=InputDocumentation(doc="Directory where intermediate result files are stored\n")), ToolInput(tag="in_ku_be_run", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_project", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_var_42", input_type=String(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_or", input_type=String(), position=3, doc=InputDocumentation(doc="")), ToolInput(tag="in_repository", input_type=String(), position=4, doc=InputDocumentation(doc="")), ToolInput(tag="in_url", input_type=String(), position=5, doc=InputDocumentation(doc=""))], outputs=[], container="quay.io/biocontainers/nextflow:20.10.0--hecda079_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Nextflow_Kuberun_V0_1_0().translate("wdl")

